************
Django Solar
************

.. image:: https://img.shields.io/pypi/v/django_solar
    :target: https://pypi.org/project/django_solar/

.. image:: https://img.shields.io/pypi/pyversions/django_solar
    :target: https://pypi.org/project/django_solar/

Django email automation with cron.

Work in Process...
